@@ -49,6 +49,11 @@ static const PropertyInfo propertiesInfo[] =
        { BeagleSearch::Contact, "fixme:Email1", 0 },
        { BeagleSearch::Contact, "vCard:FN", 0 },
        { BeagleSearch::Contact, "vCard:EMAIL", 0 },
+       { BeagleSearch::Contact, "vCard:TEL:WORK", I18N_NOOP("Business phone: %1")"<br>" },
+       { BeagleSearch::Contact, "vCard:TEL:CELL", I18N_NOOP("Mobile phone: %1")"<br>" },
+       { BeagleSearch::Contact, "vCard:TEL:HOME", I18N_NOOP("Home phone: %1")"<br>" },
+       { BeagleSearch::Contact, "vCard:URL", 0 },
+//       { BeagleSearch::Contact, "vCard:NOTE", I18N_NOOP("Note: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:BusinessPhone", I18N_NOOP("Business phone: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:HomePhone", I18N_NOOP("Home phone: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:MobilePhone", I18N_NOOP("Mobile phone: %1")"<br>" },
@@ -104,6 +109,22 @@ static const PropertyInfo propertiesInfo[] =
        { BeagleSearch::Unknown, "fixme:endtime", 0 },
        { BeagleSearch::Unknown, "fixme:location", I18N_NOOP("Location: %1")"<br>" },
        { BeagleSearch::Unknown, "fixme:page-count", I18N_NOOP("Pages: %1")"<br>" },
+// KOrganizer Calendar
+       { BeagleSearch::Calendar, "dc:title", 0 },
+       { BeagleSearch::Calendar, "fixme:location", I18N_NOOP("Location: %1")"<br>" },
+       { BeagleSearch::Calendar, "fixme:startdate", 0 },
+       { BeagleSearch::Calendar, "fixme:starttime", 0 },
+       { BeagleSearch::Calendar, "fixme:enddate", 0 },
+       { BeagleSearch::Calendar, "fixme:endtime", 0 },
+// KOrganizer Todo
+       { BeagleSearch::Todo, "dc:title", 0 },
+       { BeagleSearch::Todo, "fixme:location", I18N_NOOP("Location: %1")"<br>" },
+       { BeagleSearch::Todo, "fixme:percent-complete", I18N_NOOP("Percent complete: %1")"<br>" },
+       { BeagleSearch::Todo, "fixme:startdate", 0 },
+       { BeagleSearch::Todo, "fixme:starttime", 0 },
+       { BeagleSearch::Todo, "fixme:duetime", 0 },
+       { BeagleSearch::Todo, "fixme:duedate", 0 },
+
 //       { BeagleSearch::, "", I18N_NOOP(": %1")+"<br>" },
 //       { "", "", I18N_NOOP("") },
        { 0, 0, 0}
@@ -165,6 +186,8 @@ static const HitFlavorInfo hitflavorinfos[] =
        { BeagleSearch::Packages, "*.ebuild", 0, 0 },
        { BeagleSearch::Packages, "*.rpm", 0, "application/x-rpm" },
        { BeagleSearch::Packages, "*.deb", 0, "application/x-deb" },
+       { BeagleSearch::Calendar, 0, 0, "text/x-korganizer-event" },
+       { BeagleSearch::Todo, 0, 0, "text/x-korganizer-todo" },
        { BeagleSearch::Unknown, "file://", "File", 0 },  // mimetype wildcard must be last
        { 0, 0, 0, 0}
 };
