@@ -367,13 +367,13 @@ void SearchDlg::updateStatus()
     const int count = displayed_results.count();
     QString text;
     if (displayAmount==1)
-       text=i18n("<b>%1 results</b> found.").arg(displayed_results.count());
+       text=i18n("<b>1 result</b> found.", "<b>%n results</b> found.", count);
     else if (count==0)
        text=i18n("<qt>No results.</qt>").replace("<qt>",QString::null).replace("</qt>",QString::null);
     else if (displayOffset==0)
-       text=i18n("Best <b>%1 results of %2</b> shown.").arg(tableHits->count()).arg(displayed_results.count());
+       text=i18n("Best <b>%1 results of %2</b> shown.").arg(tableHits->count()).arg(count);
     else
-       text=i18n("Results <b>%1 through %2 of %3</b> are shown.").arg(displayOffset+1).arg(displayOffset+tableHits->count()).arg(displayed_results.count());
+       text=i18n("Results <b>%1 through %2 of %3</b> are shown.").arg(displayOffset+1).arg(displayOffset+tableHits->count()).arg(count);
 
 #if 0
     if (still_searching)
@@ -715,36 +715,82 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         item->insertHeaderWidget(2,headerEmailLabel);
         connect(headerEmailLabel, SIGNAL(leftClickedURL(const QString&)), SLOT(slotMailTo(const QString&)));
       }
+      else if (*(result->mime_type)=="text/x-korganizer-event" || *(result->mime_type)=="text/x-korganizer-todo") {
+        item->setIcon("korganizer");
+
+        QStringList _properties(result->properties);
+        QString title = takeProperty("dc:title",_properties);
+
+        QString properties;
+        QDateTime datetime;
+
+        QString starttime = takeProperty("fixme:starttime",_properties);
+        if (!starttime.isEmpty()) {
+           datetime = datetimeFromString(starttime);
+           properties = properties + i18n("Start time: %1").arg(KGlobal::locale()->formatDateTime(datetime,false)) + "<br>";
+           item->setDate(datetime.date());
+        }
+
+        QString startdate = takeProperty("fixme:startdate",_properties);
+        if (!startdate.isEmpty()) {
+           datetime = datetimeFromString(startdate);
+           properties = properties + i18n("Start date: %1").arg(KGlobal::locale()->formatDate(datetime.date(),false)) + "<br>";
+           item->setDate(datetime.date());
+        }
+
+        QString endtime = takeProperty("fixme:endtime",_properties);
+        if (!endtime.isEmpty())
+           properties = properties + i18n("End time: %1").arg(KGlobal::locale()->formatDateTime(datetimeFromString(endtime),false)) + "<br>";
+
+        QString enddate = takeProperty("fixme:enddate",_properties);
+        if (!enddate.isEmpty())
+           properties = properties + i18n("End date: %1").arg(KGlobal::locale()->formatDate(datetimeFromString(enddate).date(),false)) + "<br>";
+
+        QString duetime = takeProperty("fixme:duetime",_properties);
+        if (!duetime.isEmpty())
+           properties = properties + i18n("Due time: %1").arg(KGlobal::locale()->formatDateTime(datetimeFromString(duetime),false)) + "<br>";
+
+        QString duedate = takeProperty("fixme:duedate",_properties);
+        if (!duedate.isEmpty())
+           properties = properties + i18n("Due date: %1").arg(KGlobal::locale()->formatDate(datetimeFromString(duedate).date(),false)) + "<br>";
+
+        BeagleSearch::PropertyList::iterator it;
+        for ( it = _properties.begin(); it != _properties.end(); ++it )
+                properties=properties+(*it);
+
+        if (!properties.isEmpty())
+           item->setDescriptionText("<qt>"+properties+"</qt>");
+
+        if (result->snippet)
+            item->setPropertiesText("<qt>"+*(result->snippet)+"</qt>");
+
+        QLabel *headerLabel = new QLabel(item);
+        if (*(result->mime_type)=="text/x-korganizer-event")
+           headerLabel->setText(i18n("Meeting:"));
+        else
+           headerLabel->setText(i18n("To-do:"));
+        headerLabel->setAlignment(headerLabel->alignment() | Qt::SingleLine);
+        item->insertHeaderWidget(0,headerLabel);
+
+        KerryLabel *headerNameLabel = new KerryLabel(item);
+        headerNameLabel->setText(title);
+        headerNameLabel->setURL(item->uri());
+        item->insertHeaderWidget(1,headerNameLabel);
+        connect(headerNameLabel, SIGNAL(leftClickedURL(const QString&)), SLOT(slotOpenKOrganizer(const QString&)));
+      }
       else if ((*(result->uri)).startsWith("kabc:/")) {
         item->setIcon("kaddressbook");
 
         QStringList _properties(result->properties);
         QString name = takeProperty("vCard:FN",_properties);
         QString email = takeProperty("vCard:EMAIL",_properties);
+        QString homepage = takeProperty("vCard:URL",_properties);
 
         QString properties;
         BeagleSearch::PropertyList::iterator it;
         for ( it = _properties.begin(); it != _properties.end(); ++it )
                 properties=properties+(*it);
 
-        if (!m_addressBook)
-           m_addressBook = KABC::StdAddressBook::self( false );
-
-        KABC::Addressee addresseee = m_addressBook->findByUid( item->uri().mid(8,10) );
-        QString number;
-
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Work).number();
-        if (!number.isEmpty())
-           properties=properties+i18n("Business phone: %1").arg(number)+"<br>";
-
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Cell).number();
-        if (!number.isEmpty())
-           properties=properties+i18n("Mobile phone: %1").arg(number)+"<br>";
-
-        number = addresseee.phoneNumber(KABC::PhoneNumber::Home).number();
-        if (!number.isEmpty())
-           properties=properties+i18n("Home phone: %1").arg(number)+"<br>";
-
         if (!properties.isEmpty())
            item->setDescriptionText("<qt>"+properties+"</qt>");
 
@@ -765,6 +811,7 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         	item->insertHeaderWidget(2,headerEmailLabel);
         	connect(headerEmailLabel, SIGNAL(leftClickedURL(const QString&)), SLOT(slotMailTo(const QString&)));
         }
+
       }
       else if (*(result->mime_type)=="message/rfc822" || (*(result->uri)).startsWith("email:/") ) {
         item->setIcon("mail_generic");
@@ -1102,6 +1149,7 @@ void SearchDlg::itemUncollapsed(HitWidget* item)
 void SearchDlg::searchHasOutput(BeagleSearch::BeagleResultList &items)
 {
     BeagleSearch::BeagleResultList* searchResults = new BeagleSearch::BeagleResultList;
+    bool forceRebuildDisplay = false;
 
     for (BeagleSearch::BeagleResultList::ConstIterator it = items.begin(); it != items.end(); ++it) {
       BeagleSearch::beagle_result_struct* result = (*it); 
@@ -1109,18 +1157,44 @@ void SearchDlg::searchHasOutput(BeagleSearch::BeagleResultList &items)
           KURL kurl(*(result->uri));
           *(result->uri)=kurl.url();
       }
-      if (!checkUriInResults(*(result->uri)) && !(*(result->uri)).startsWith("kbookmark:/")) {
+
+      if ((*(result->uri)).startsWith("kbookmark:/"))
+	 continue;
+
+      if (!checkUriInResults(*(result->uri))) {
          result->show_expanded=showBigTiles;
          results.append(result);
          searchResults->append(result);
+      } else if (((*result->uri)).startsWith("kabc:/")) {
+	 int i;
+	 // Replace the previous kabc result with this one
+	 // The only duplicates will be between kabc and kaddrbook backend, and the backend
+	 // results will override kabc ones.
+	 kdDebug() << "Replacing old result" << endl;
+	 forceRebuildDisplay = true;
+	 for(i = 0; i < (int)displayed_results.count(); ++i)
+      	 {
+      	    BeagleSearch::beagle_result_struct *old_result = displayed_results.at(i);
+      	    if (*(result->uri)==(*(old_result->uri))) {
+      	      displayed_results.replace(i,result);
+      	      break;
+      	   }
+      	 }
+      	 for(i = 0; i < (int)results.count(); ++i)
+      	 {
+      	    BeagleSearch::beagle_result_struct *old_result = results.at(i);
+      	    if (*(result->uri)==(*(old_result->uri))) {
+      	      results.replace(i,result);
+      	      break;
+	    }
+	 }
       }
     }
-    displayResults(*searchResults);
+    displayResults(*searchResults, forceRebuildDisplay);
 }
 
-void SearchDlg::displayResults(BeagleSearch::BeagleResultList &items)
+void SearchDlg::displayResults(BeagleSearch::BeagleResultList &items, bool rebuildDisplay)
 {
-    bool rebuildDisplay = false;
     if (displayAmount==1)
       tableHits->setUpdatesEnabled(false);
     for (BeagleSearch::BeagleResultList::ConstIterator it = items.begin(); it != items.end(); ++it) {
@@ -1269,6 +1343,10 @@ void SearchDlg::slotOpen()
       {
         slotOpenEvolution(item->uri());
       }
+      else if (item->uri().startsWith("korganizer:/"))
+      {
+        slotOpenKOrganizer(item->uri());
+      }
       else if (item->uri().startsWith("mailbox:/") && item->uri().find("thunderbird")>0)
       {
         slotOpenThunderbird(item->uri());
@@ -1344,6 +1422,27 @@ void SearchDlg::slotOpenKAddressBook(const QString &uid)
     }
 }
 
+void SearchDlg::slotOpenKOrganizer(const QString &/*uri*/)
+{
+    HitWidget* item = static_cast<HitWidget*>(sender()->parent());
+    if (item) {
+       if (ensureServiceRunning("korganizer")) {
+         QString mimetype = item->mimetype();
+         QByteArray data;
+         QDataStream arg(data, IO_WriteOnly);
+
+         if (mimetype=="text/x-korganizer-event") {
+            kapp->dcopClient()->send("korganizer","CalendarIface","showEventView()", data);
+
+            arg << item->date();
+            kapp->dcopClient()->send("korganizer","CalendarIface","goDate(QDate)", data);
+         }
+         else
+            kapp->dcopClient()->send("korganizer","CalendarIface","showTodoView()", data);
+      }
+   }
+}
+
 void SearchDlg::slotOpenKNotes(const QString &noteid)
 {
     if (ensureServiceRunning("knotes")) {
@@ -1750,6 +1849,21 @@ void SearchDlg::searchAddressbook()
         result->uri=new QString("kabc:///"+(*it).uid());
 	*(result->properties).append("vCard:FN="+realName);
         *(result->properties).append("vCard:EMAIL="+(*it).preferredEmail());
+
+	// Add phone numbers
+	QString number;
+        number = (*it).phoneNumber(KABC::PhoneNumber::Work).number();
+        if (!number.isEmpty())
+	   *(result->properties).append(i18n(I18N_NOOP("Business phone: %1")"<br>").arg(number));
+
+        number = (*it).phoneNumber(KABC::PhoneNumber::Cell).number();
+        if (!number.isEmpty())
+	   *(result->properties).append(i18n(I18N_NOOP("Mobile phone: %1")"<br>").arg(number));
+
+        number = (*it).phoneNumber(KABC::PhoneNumber::Home).number();
+        if (!number.isEmpty())
+	   *(result->properties).append(i18n(I18N_NOOP("Home phone: %1")"<br>").arg(number));
+
 	result->tilegroup = BeagleSearch::Contact;
 	result->score = 0.0;
 	result->show_expanded=showBigTiles;
