@@ -107,6 +107,7 @@ class SearchDlg : public HitsLayout, virtual public dcopIface
     void slotOpenDir();
     void slotMailTo(const QString&);
     void slotOpenEvolution(const QString&);
+    void slotOpenKOrganizer(const QString&);
     void slotOpenThunderbird(const QString&);
     void slotOpenKAddressBook(const QString&);
     void slotOpenKNotes(const QString&);
@@ -139,7 +140,7 @@ class SearchDlg : public HitsLayout, virtual public dcopIface
 
     void customEvent (QCustomEvent *e);
     bool pending_showQuickTips;
-    void displayResults(BeagleSearch::BeagleResultList &items);
+    void displayResults(BeagleSearch::BeagleResultList &items, bool forceRebuildDisplay = false);
     bool mimeTypeMatch( const QString& mimeType, const QStringList& mimeList ) const;
     bool canPreview( KFileItem* item );
     void updatePreviewMimeTypes();
